#!/usr/bin/env bash

function bd_detect_distro() {
    rh_release="/etc/redhat-release"
    os_release="/etc/os-release"
    if [ -f ${rh_release} ]; then
		if [ -n "`grep 'CentOS Stream' ${rh_release}`" ]; then
			export distro='CentOS Stream'
			export version=`cat /etc/redhat-release |sed "s/.*release//g"|awk '{print $1}'`
            export distro_version=${version}
            export distro_version_major=${version}
        elif [ -n "`grep CentOS ${rh_release}`" ]; then
            export distro='CentOS'
            export version=`cat /etc/redhat-release |sed "s/.*release//g"|awk '{print $1}' | awk -F. '{print $1"."$2}'`
            export version_first=`echo ${version} | cut -d '.' -f 1`
            export version_second=`echo ${version} | cut -d '.' -f 2`
            export distro_version=${version}
            export distro_version_major=${version_first}
            export distro_version_minor=${version_second}
            # TODO rename version_first to distro_version_major in all patches
            # TODO rename version to distro_version in all patches
        elif [ -n "`grep Baidu ${rh_release}`" ]; then
            export distro='Baidu'
            # e.g. version=2.0
            export version=`cat /etc/redhat-release |sed "s/.*release//g"|awk '{print $1}' | awk -F. '{print $1"."$2}'`
            # e.g. versio_first=2
            export version_first=`echo ${version} | cut -d '.' -f 1`
            # e.g. version_second=0
            export version_second=`echo ${version} | cut -d '.' -f 2`
            export distro_version=${version}
            export distro_version_major=${version_first}
            export distro_version_minor=${version_second}
        elif [ -n "`grep Fedora  ${rh_release}`" ]; then
            export distro='Fedora'
            export version=$(cat /etc/redhat-release |sed "s/.*release//g"|awk '{print $1}')
            export distro_version=${version}
        elif [ -n "`grep 'Red Hat Enterprise' ${rh_release}`" ]; then
            export distro='rhel'
            export version=$(cat /etc/redhat-release |sed "s/.*release//g"|awk '{print $1}')
            export version_first=`echo ${version} | cut -d '.' -f 1`
            export version_second=`echo ${version} | cut -d '.' -f 2`
            export distro_version=${version}
            export distro_version_major=${version_first}
            export distro_version_minor=${version_second}
        elif [ -n "`grep 'Rocky' ${rh_release}`" ]; then
            export distro='Rocky'
            export version=$(cat /etc/redhat-release |sed "s/.*release//g"|awk '{print $1}' | awk -F. '{print $1"."$2}')
            export version_first=`echo ${version} | cut -d '.' -f 1`
            export version_second=`echo ${version} | cut -d '.' -f 2`
            export distro_version=${version}
            export distro_version_major=${version_first}
            export distro_version_minor=${version_second}
        elif [ -n "`grep 'AlmaLinux' ${rh_release}`" ]; then
            export distro='AlmaLinux'
            export version=$(cat /etc/redhat-release |sed "s/.*release//g"|awk '{print $1}' | awk -F. '{print $1"."$2}')
            export version_first=`echo ${version} | cut -d '.' -f 1`
            export version_second=`echo ${version} | cut -d '.' -f 2`
            export distro_version=${version}
            export distro_version_major=${version_first}
            export distro_version_minor=${version_second}
        else
            export distro='unknow'
            export distro_version='unknow'
        fi   
     elif [ -f ${os_release} ] \
        && [ -n "`grep openSUSE ${os_release}`" ]; then
        source ${os_release}
        export distro='openSUSE'
        export version=${VERSION}
        export version_first=`echo ${version} | cut -d '.' -f 1`
        export version_second=`echo ${version} | cut -d '.' -f 2`
        export distro_version=${version}
        export distro_version_major=${version_first}
        export distro_version_minor=${version_second}
    elif [ -n "`lsb_release -i | grep ebian`" ] || \
        [ -n "`lsb_release -i | grep buntu`" ]; then
        [ -n "`lsb_release -i | grep ebian`" ] && export distro='Debian'
        [ -n "`lsb_release -i | grep buntu`" ] && export distro='Ubuntu'
        export version=`lsb_release -r | awk '{print $2}'`
        export version_first=`echo ${version} | cut -d '.' -f 1`
        export version_second=`echo ${version} | cut -d '.' -f 2`
        export distro_version=${version}
        export distro_version_major=${version_first}
        export distro_version_minor=${version_second}
    else
        export distro='unknow'
        export distro_version='unknow'
    fi
}

function bd_base_info() {
    arch=$(uname -p)
    if [ "${arch}" = "unknown" ];then
        arch=`file /bin/ls | awk -F',' '{print $2}' | tr  '-' '_'  | tr -d ' \n'`
    elif [ "${arch}" == "i686" -o "${arch}" = "Intel80386" ];then
        arch='i386'
    fi
    if [ -d /sys/firmware/efi ]; then
        export boot_mode="UEFI"
    else
        export boot_mode="BIOS(Legacy)"
    fi
    export arch
    export platform=$(uname -s)
    export kernel_version=$(uname -r)
}

bd_detect_distro
bd_base_info