#!/usr/bin/env bash

function bd_check_bsm_agent() {
    write_file $split_line
    write_file "[ check bsm agent ]"

    if [[ "$distro" == "CentOS" || "$distro" == "Baidu" || "$distro" == "CentOS Stream" || 
      "$distro" == "Rocky" || "$distro" == "AlmaLinux" || "$distro" == "rhel" ]]; then
        if [[ "$distro_version_major" -ge 7 || "$distro" == "Baidu" ]]; then
            systemctl status bsm-agent-upgrader 2> /dev/null | grep -q "active (running)"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the bsm-agent service is not running."
                return ${RETURN_WARNING}
            fi
            flag=$(systemctl list-unit-files  | grep bsm-agent-upgrader.service | awk '{print $2}')
            if [ "$flag" = "disable" ] || [ "$flag" = "inactive" ]; then
                write_file "\tWARNING: the bsm-agent service is disabled."
                write_file "\tWARNING: please enable bsm-agent service."
                return ${RETURN_WARNING}
            fi
        else
            chkconfig --list | grep bsm-agent-upgrader | grep -qE "3:on|4:on|5:on"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the bsm-agent service is disabled."
                write_file "\tWARNING: please enable bsm-agent service."
                return ${RETURN_WARNING}
            fi
        fi
    fi 

    if [[ "$distro" == "Ubuntu" || "$distro" == "Debian" ]]; then
        if [ "$distro_version_major" -ge "16" ]; then
            systemctl status bsm-agent-upgrader 2> /dev/null | grep -q "active (running)"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the bsm-agent service is not running."
                return ${RETURN_WARNING}
            fi
        else
            service bsm-agent-upgrader status 2> /dev/null | head -n 5 | grep -q "running"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the bsm-agent service is not running."
                return ${RETURN_WARNING}
            fi
        fi
    fi
    return ${RETURN_SUCCESS}
}

function bd_check_bcm_agent() {
    write_file ${split_line}
    write_file "[ check bcm agent ]"    

    command -v rpm 1>/dev/null 2>&1
    if [ $? -eq 0 ]; then
        rpm -q bcm-agent &>/dev/null
        if [ $? -ne 0 ]; then
            write_file "\tWARNING: the bcm agent is not installed."
            return ${RETURN_WARNING}
        fi
    fi

    command -v dpkg-query 1>/dev/null 2>&1
    if [ $? -eq 0 ]; then
        dpkg-query -W -f='${Package} ${Status}\n' | grep -w "^bcm-agent" | grep -q "installed"
        if [ $? -ne 0 ]; then
            write_file "\tWARNING: the bcm agent is not installed."
            return ${RETURN_WARNING}
        fi
    fi

    if [[ "$distro" == "CentOS" || "$distro" == "Baidu" || "$distro" == "CentOS Stream" || 
      "$distro" == "Rocky" || "$distro" == "AlmaLinux" || "$distro" == "rhel" ]]; then
        if [[ "$distro_version_major" -ge 7 || "$distro" == "Baidu" ]]; then
            systemctl status bcm-agent 2> /dev/null | grep -q "active (running)"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the bcm-agent service is not running."
                return ${RETURN_WARNING}
            fi
            flag=$(systemctl list-unit-files  | grep bcm-agent.service | awk '{print $2}')
            if [[ "$flag" == "disable" || "$flag" == "inactive" ]]; then
                write_file "\tWARNING: the bcm-agent service is disabled."
                write_file "\tWARNING: please enable bcm-agent service."
                return ${RETURN_WARNING}
            fi
        else
            chkconfig --list | grep bcm-agent | grep -qE "3:on|4:on|5:on"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the bcm-agent service is disabled."
                write_file "\tWARNING: please enable bcm-agent service."
                return ${RETURN_WARNING}
            fi
        fi
    fi 

    if [[ "$distro" == "Ubuntu" || "$distro" == "Debian" ]]; then
        if [ "$distro_version_major" -ge "16" ]; then
            systemctl status bcm-agent 2> /dev/null | grep -qE "bcm-agent.service; enabled|running"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the bcm-agent service is not running."
                return ${RETURN_WARNING}
            fi
        else
            service bcm-agent status 2> /dev/null | head -n 5 | grep -q "running"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the bcm-agent service is not running."
                return ${RETURN_WARNING}
            fi
        fi
    fi
    return ${RETURN_SUCCESS}
}

function bd_check_has_agent() {
    write_file $split_line
    write_file "[ check has agent ]"

    if [[ "$distro" == "CentOS" || "$distro" == "Baidu" || "$distro" == "CentOS Stream" || 
      "$distro" == "Rocky" || "$distro" == "AlmaLinux" || "$distro" == "rhel" ]]; then
        if [[ "$distro_version_major" -ge 7 || "$distro" == "Baidu" ]]; then
            systemctl status has-agent 2> /dev/null | grep -q "active (running)"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the has-agent service is not running."
                return ${RETURN_WARNING}
            fi
            flag=$(systemctl list-unit-files  | grep has-agent.service | awk '{print $2}')
            if [[ "$flag" == "disable" || "$flag" == "inactive" ]]; then
                write_file "\tWARNING: the has-agent service is disabled."
                write_file "\tWARNING: please enable has-agent service."
                return ${RETURN_WARNING}
            fi
        else
            chkconfig --list | grep has-agent | grep -qE "3:on|4:on|5:on"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the has-agent service is disabled."
                write_file "\tWARNING: please enable has-agent service."
                return ${RETURN_WARNING}
            fi
        fi
    fi 

    if [[ "${distro}" == "Ubuntu" || "${distro}" == "Debian" ]]; then
        if [ "$distro_version_major" -ge "16" ]; then
            systemctl status has-agent 2> /dev/null | grep -q "active (running)"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the has-agent service is not running."
                return ${RETURN_WARNING}
            fi
        else
            service has-agent status 2> /dev/null | head -n 5 | grep -q "running"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the has-agent service is not running."
                return ${RETURN_WARNING}
            fi
        fi
    fi
    return ${RETURN_SUCCESS}
}