#!/usr/bin/env bash

function bd_check_cloud_init(){
    write_file ${split_line}
    write_file "[ check cloud-init ]"    

    command -v rpm 1>/dev/null 2>&1
    if [ $? -eq 0 ]; then
        rpm -q cloud-utils-growpart 1>/dev/null 2>&1
        if [ $? -ne 0 ]; then
            write_file "\tCRITICAL: the cloud-init is not installed."
            return ${RETURN_CRITICAL}
        fi
        return ${RETURN_SUCCESS}
    fi

    command -v dpkg-query 1>/dev/null 2>&1
    if [ $? -eq 0 ]; then
        dpkg-query -W -f='${Package} ${Status}\n' | grep -w "^cloud-init" | grep -q "installed"
        if [ $? -ne 0 ]; then
            write_file "\tCRITICAL: the cloud-init is not installed."
            return ${RETURN_CRITICAL}
        fi
        return ${RETURN_SUCCESS}
    fi
}

function bd_check_resize_fs(){
    write_file ${split_line}
    write_file "[ check online resize fs ]"

    command -v rpm 1>/dev/null 2>&1
    if [ $? -eq 0 ]; then
        rpm -q cloud-utils-growpart 1>/dev/null 2>&1
        if [ $? -ne 0 ]; then
            write_file "\tCRITICAL: the cloud-guest-utils is not installed."
            return ${RETURN_WARNING}
        fi
        return ${RETURN_SUCCESS}
    fi

    command -v dpkg-query 1>/dev/null 2>&1
    if [ $? -eq 0 ]; then
        dpkg-query -W -f='${Package} ${Status}\n' | grep -w "^cloud-guest-utils" | grep -q "installed"
        if [ $? -ne 0 ]; then
            write_file "\tCRITICAL: the cloud-guest-utils is not installed."
            return ${RETURN_CRITICAL}
        fi
        return ${RETURN_SUCCESS}
    fi

    if [ ! -f /etc/cloud/cloud.cfg ]; then
        write_file "\tWARNING: /etc/cloud/cloud.cfg doesn't exist.."
        return ${RETURN_WARNING}
    fi

    res=$(grep -ri "growpart" /etc/cloud/cloud.cfg)
    if [ -z "${res}" ]; then
        write_file "\tWARNING: the 'growpart' configuration option was not retrieved in the configuration file."
        return ${RETURN_WARNING}
    else
        echo "${res}" | grep "false" 1>/dev/null 2>&1
        if [ $? -eq 0 ]; then
            write_file "\tWARNING: the 'growpart' configuration option is set to false in cloud-init config file."
            return ${RETURN_WARNING}
        fi
    fi
    return ${RETURN_SUCCESS}
}