#!/usr/bin/env bash

function risk_level() {
    case $1 in
    "nvme") echo ${RETURN_WARNING} ;;
    "mlx5") echo ${RETURN_WARNING} ;;
    "virtio") echo ${RETURN_CRITICAL} ;;
    esac
}

initrdfile_info=
function check_driver() {
    write_file ${split_line}
    write_file "[ check $1 driver ]"

    ret=
    s_cmd=
    driver_name=$1
    linux_config=$2
    module_name=$3

    if [ ${driver_name} = "nvme" ]; then
        grep -q 'nvme_core.io_timeout=4294967295' /proc/cmdline && grep -q \
            'nvme_core.admin_timeout=4294967295' /proc/cmdline
        if [ $? -ne 0 ]; then
            write_file "\tWARNING: the nvme driver requires the kernel boot parameters \
nvme_core.io_timeout=4294967295 and nvme_core.admin_timeout=4294967295."

            return ${RETURN_WARNING}
        fi
    fi

    command -v lsinitrd 1>/dev/null 2>&1
    if [ $? -eq 0 ]; then
        s_cmd="lsinitrd"
    else
        command -v lsinitramfs 1>/dev/null 2>&1
        if [ $? -eq 0 ]; then
            s_cmd="lsinitramfs"
        fi
    fi

    if [ -z "${s_cmd}" ]; then
        write_file ${split_line}
        write_file "\tWARNING: can't find lsinitrd or lsinitramfs command."
        return ${RETURN_WARNING}
    fi

    # Check if the current kernel contains the driver
    current_kernel=$(uname -r)
    kernel_config="/boot/config-${current_kernel}"
    if [ -e ${kernel_config} ] && [ -r ${kernel_config} ]; then
        ret=$(grep -wE ${linux_config} ${kernel_config} | awk -F '=' '{print $2}')
        if [ -n "${ret}" ] && [ "${ret}" = 'y' ]; then
            return ${RETURN_SUCCESS}
        fi
    fi

    ret=1
    initrdfile=$(find /boot -maxdepth 1 -type f -regextype posix-extended -regex \
        '.*/init[^/]*-[^/]*(\.img)?' -o -regex '.*/init[^/]*\.img-[^/]*') 1>/dev/null 2>&1
    if [ -n "${initrdfile}" ]; then
        if [ -z "${initrdfile_info}" ]; then
            initrdfile_info=$(${s_cmd} ${initrdfile})
        fi
        echo ${initrdfile_info} | grep -q "$module_name.ko" 1>/dev/null 2>&1
        [ $? -eq 0 ] && ret=0
    fi

    driver_module=$(find /lib/modules/${kernel_version}/kernel/drivers \
	-type f -name "${module_name}.ko*")
    [ -n "${driver_module}" ] && ret=0
    if [ ${ret} -eq 0 ]; then return ${RETURN_SUCCESS}; fi
    write_file "\tCRITICAL: can't fine the ${driver_name} driver."
    return $(risk_level ${driver_name})
}

function bd_check_mlx5_driver(){
    check_driver "mlx5" "CONFIG_MLX5_CORE" "mlx5_core"
}
function bd_check_virtio_driver(){
    check_driver "virtio" "CONFIG_VIRTIO_BLK" "virtio_blk"
}
function bd_check_nvme_driver(){
    check_driver "nvme" "CONFIG_NVME_CORE" "nvme-core"
}
