#!/usr/bin/env bash

function check_ext4_csum(){
    root_dev=$(grep -v "#" "/etc/fstab" | grep -v "^;" | grep "ext4" | head -n 1 | awk '{print $1}')
    if [ -z "${root_dev}" ]; then
        return ${RETURN_SUCCESS}
    fi

    ret=$(echo ${root_dev} | grep "UUID")
    if [ "${ret}" != "" ]; then
        dev_uuid=$(echo "${root_dev}" | awk -F "=" '{print $2}')
        root_dev=$(blkid | grep "${dev_uuid}" | awk -F ':' '{print $1}')
    fi

    command -v dumpe2fs 1>/dev/null 2>&1
    if [ $? -eq 0 ]; then
        dumpe2fs ${root_dev} 2>/dev/null | grep "Filesystem features" | grep "metadata_csum" 1>/dev/null 2>&1
        [ $? -eq 0 ] && return ${RETURN_WARNING} || return ${RETURN_SUCCESS}
    fi
}

function get_fs_type(){
    if [ -e /etc/fstab ]; then
        ret=$(grep -v "#" "/etc/fstab" | grep -v "^;" | grep -v -E "ext2|ext3|ext4|swap|tmpfs|devpts|sysfs|proc|debugfs")
        if [ -n "${ret}" ]; then
            return 1
        else
            return 0
        fi
    else
        return 2
    fi
}

function bd_check_fs_type(){
    write_file ${split_line}
    write_file "[ check file system ]"

    get_fs_type
    case $? in
    0)
        check_ext4_csum
        if [ $? -eq 0 ]; then
            return ${RETURN_SUCCESS}
        else
            write_file "\tWARNING: bcc don't support ext4 with the features of metadata_csum."
            return ${RETURN_WARNING}
        fi
        ;;
    1)
        write_file "\tWARNING: the device file you are using exists in a type other than ext2/ext3/etx4."
        return ${RETURN_WARNING}
        ;;
    2)
        write_file  "\tWARNING: /etc/fstab doesn't exist."
        return ${RETURN_WARNING}
        ;;
    *)
        write_file "\tWARNING: unknown error."
        return ${RETURN_WARNING}
    esac
}

# check whether the variable is a string
function get_value_type(){
    case $1 in
        [0-9] | [0-9][0-9]*)
            return 0
            ;;
        *)
            return 1
            ;;
    esac
}

function check_fstab_format(){
    fstab_path="/etc/fstab"
    while IFS= read -r line; do
        flag=0
        if [[ -n $line ]] && [[ ! "$line" =~ ^#.* ]]; then
            split_array=($line)
            length=${#split_array[@]}
            if [ $length -ne 6 ]; then flag=1; fi

            for ((i=0; i < 4; i++)); do
                item=${split_array[$i]}
                get_value_type $item
                if [ $? -eq 0 ]; then flag=1; fi
            done

            for ((i=4; i < 6; i++)); do
                item=${split_array[$i]}
                get_value_type $item
                if [ $? -eq 1 ]; then flag=1; fi
            done
            if [ ${flag} -eq 1 ]; then 
                return ${RETURN_CRITICAL}
            fi
        fi
    done < "${fstab_path}"
    return ${RETURN_SUCCESS}
}

function bd_check_fstab_config(){
    write_file ${split_line}
    write_file "[ check fstab config ]"

    if [[ ! -f /etc/fstab && ! -r /etc/fstab ]]; then
        write_file "\tCRITICAL: /etc/fstab doesn't exist or can not be read."
        return ${RETURN_CRITICAL}
    fi

    ret=0
    grep -v "#" "/etc/fstab" | grep -v "^;"| grep -v "^$" | grep -v "UUID" &> /dev/null
    if [ $? -eq 0 ];then
        ret=1
        write_file "\tCRITICAL: there are partitions that are not mounted using UUID."
    fi

    check_fstab_format
    if [ $? -ne 0 ]; then
        ret=1
        write_file "\tCRITICAL: there is a format error."
    fi 

    if [ ${ret} -eq 0 ]; then 
        return ${RETURN_SUCCESS}
    else 
        return ${RETURN_CRITICAL}
    fi
}