#!/usr/bin/env bash

function bd_check_grub(){
    write_file ${split_line}
    write_file "[ check grub ]"

    grub_file=""
    if [ -e ${s_grub_file} ]; then
        grub_file=${s_grub_file}
    elif [ -e ${s_efi_grub} ]; then
        grub_file=${s_efi_grub}
    fi

    if [ ! -f ${grub_file} ]; then
        write_file "\tCRITICAL: grub configuration file does not exist."
        return ${RETURN_CRITICAL}
    fi

    grub_str=$(cat ${grub_file} |
        grep -v "^#" |
        grep "$(uname -r)" |
        grep "root" |
        awk -F "=" '{print $3}' |
        awk '{print $1}' |
        awk 'NR==1 {print}'
    )
    if [ -z "$grub_str" ]; then
        grub_str=$(cat "${grub_file}" |
            grep -v "^#" |
            grep "root" |
            grep "kernelopts" |
            grep -i "uuid" |
            awk -F '=' '{print $4}' |
            awk '{print $1}'
        )
        if [ -z "${grub_str}" ]; then
            write_file "\tCRITICAL: in ${grub_file}, the root partition is not mounted using UUID."
            return ${RETURN_CRITICAL}
        fi
    fi
    blkid_list=$(blkid | grep -o 'UUID="[^"]*"' | awk -F'"' '{print $2}')
    for id in ${blkid_list}; do
        if [ ${grub_str} = "${id}" ]; then
            return ${RETURN_SUCCESS}
        fi
    done
    
    write_file "\tCRITICAL: grub root UUID is not the same as the disk UUID."
    return ${RETURN_CRITICAL}
}