#!/usr/bin/env bash

function bd_check_hosteye() {
    write_file ${split_line}
    write_file "[ check hosteye ]"    

    command -v rpm 1>/dev/null 2>&1
    if [ $? -eq 0 ]; then
        rpm -q hosteye 1>/dev/null 2>&1
        if [ $? -ne 0 ]; then
            write_file "\tWARNING: the hosteye is not installed."
            return ${RETURN_WARNING}
        fi
    fi

    command -v dpkg-query 1>/dev/null 2>&1
    if [ $? -eq 0 ]; then
        dpkg-query -W -f='${Package} ${Status}\n' | grep -w "^hosteye" | grep -q "installed"
        if [ $? -ne 0 ]; then
            write_file "\tWARNING: the hosteye is not installed."
            return ${RETURN_WARNING}
        fi
    fi

    if [[ "$distro" == "CentOS" || "$distro" == "Baidu" || "$distro" == "CentOS Stream" || \
        "$distro" == "Rocky" || "$distro" == "AlmaLinux" || "$distro" == "rhel" ]]; then
        if [[ "$distro_version_major" -ge "7" || "${distro}" = "Baidu" ]]; then
            systemctl status hosteye 2> /dev/null | grep -q "active (running)"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the hosteye service is not running."
                return ${RETURN_WARNING}
            fi
            flag=$(systemctl list-unit-files  | grep hosteye.service | awk '{print $2}')
            if [ "$flag" = "disable" ] || [ "$flag" = "inactive" ]; then
                write_file "\tWARNING: the hosteye service is disabled."
                write_file "\tWARNING: please enable hosteye service."
                return ${RETURN_WARNING}
            fi
        else
            chkconfig --list | grep hosteye | grep -qE "3:on|4:on|5:on"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the hosteye service is disabled."
                write_file "\tWARNING: please enable hosteye service."
                return ${RETURN_WARNING}
            fi
        fi
    fi 

    if [[ "${distro}" = "Ubuntu" || "${distro}" = "Debian" ]]; then
        if [ "$distro_version_major" -ge "16" ]; then
            systemctl status hosteye 2> /dev/null | grep -q "active (running)"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the hosteye service is not running."
                return ${RETURN_WARNING}
            fi
        else
            service hosteye status 2> /dev/null | head -n 5 | grep -q "running"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the hosteye service is not running."
                return ${RETURN_WARNING}
            fi
        fi
    fi
    return ${RETURN_SUCCESS}
}