#!/usr/bin/env bash

function bd_check_network_config(){
    write_file ${split_line}
    write_file "[ check network config ]"

    ret=0
    if [[ "$distro" == "CentOS" || "$distro" == "Baidu" || "$distro" == "CentOS Stream" || 
        "$distro" == "Rocky" || "$distro" == "AlmaLinux" || "$distro" == "rhel" ]]; then
        discard_ignored_files='/\(~\|\.bak\|\.orig\|\.rpmnew\|\.rpmorig\|\.rpmsave\)$/d'
        interfaces=($(ls /etc/sysconfig/network-scripts/ifcfg* | 
            sed -e "${discard_ignored_files}" \
                -e '/$ifcfg-lo$\|:\|ifcfg-.*-range\|:\|ifcfg-virb*$/d' \
                -e '/ifcfg-[A-Za-z0-9#\._-]\+$/ { 
                    s/^ifcfg-//g;
                    s/[0-9]/ &/
                }' | 
            sort -k 1,1 -k 2n | 
            sed 's/ //'
        ))

        if [ -z "${interfaces}" ]; then
            write_file "\tCRITICAL: can't find network config file on your system."
            return ${RETURN_CRITICAL}
        fi

        for interface in ${interfaces[*]}
        do
            result=$(grep -i "BOOTPROTO" ${interface} | awk -F "=" '{print $2}')
            bootproto=$(echo ${result} | tr -d \'\")
            if [ "${bootproto}" != "dhcp" ]; then
                write_file "\tCRITICAL: in ${interface}, the BOOTPROTO is not \"dhcp\"."
                [ ${ret} -eq 1 ] || ret=1
            fi
        done
    fi

    if [[ "$distro" == "Ubuntu" || "$distro" == "Debian" ]]; then
        interfaces=($(ls /sys/class/net | grep -v lo))
        if [ -z "${interfaces}" ]; then
            write_file "\tCRITICAL: can't find network device."
            return ${RETURN_CRITICAL}
        fi

        for interface in ${interfaces[*]}
        do
            state=$(cat /sys/class/net/${interface}/operstate)
            if [ "${state}" != "up" ]; then
                continue
            fi
            if [[ "${distro}" = "Ubuntu" && ${distro_version_major} -ge 17 ]]; then
                command -v netplan 1>/dev/null 2>&1
                if [ $? -ne 0 ]; then
                    write_file "\tCRITICAL: can't find the netplan command on your system."
                    return ${RETURN_CRITICAL}
                fi
                netplan get ethernets.${interface}.dhcp4 | grep -q "true"
                if [ $? -ne 0 ]; then
                    write_file "\tCRITICAL: the NIC \"${interface}\" isn't set to dhcp mode."
                    [ ${ret} -eq 1 ] || ret=1
                fi
            else
                cat /etc/network/interfaces | grep -q "iface ${interface}"
                if [ $? -eq 0 ]; then
                    cat /etc/network/interfaces | grep "iface ${interface}" | grep -q "dhcp"
                    if [ $? -ne 0 ]; then
                        write_file "\tCRITICAL: the NIC \"${interface}\" isn't set to dhcp mode."
                        [ ${ret} -eq 1 ] || ret=1
                    fi
                else
                    grep -r "iface ${interface}" /etc/network/interfaces.d/ | grep -v "^#"
                    if [ $? -ne 0 ]; then
                        write_file "\tCRITICAL: can't find NIC ${interface}\'s configuration."
                        [ ${ret} -eq 1 ] || ret=1
                    else
                        grep -r "iface ${interface}" /etc/network/interfaces.d/ | grep -v "^#" | grep -q "dhcp"
                        if [ $? -ne 0 ]; then
                            write_file "\tCRITICAL: the NIC \"${interface}\" isn't set to dhcp mode."
                            [ ${ret} -eq 1 ] || ret=1
                        fi
                    fi
                fi
            fi
        done
    fi

    net_rule_file="/etc/udev/rules.d/70-persistent-net.rules"
    if [ -e ${net_rule_file} ]; then
        result=$(grep -vE '^$|^#' ${net_rule_file})
        if [ -n "${result}" ]; then
            write_file "\tCRITICAL: please empty or delete the rule file: ${net_rule_file}"
            [ ${ret} -eq 1 ] || ret=1
        fi
    fi
    
    if [ "${ret}" -eq 1 ]; then return ${RETURN_CRITICAL}; else return ${RETURN_SUCCESS}; fi
}