#!/usr/bin/env bash

function bd_check_sshd_service(){
    write_file $split_line
    write_file "[ check sshd service ]"

    if [[ "${distro}" == "CentOS" || "${distro}" == "Baidu" || "${distro}" == "CentOS Stream" || 
        "${distro}" == "Rocky" || "${distro}" == "AlmaLinux" || "${distro}" == "rhel" ]]; then
        rpm -q openssh-server 1>/dev/null 2>&1
    elif [[ "${distro}" = "Ubuntu" || "${distro}" = "Debian" ]]; then
        dpkg-query -W -f='${Package} ${Status}\n' | grep -w "^openssh-server" | grep -q "installed"
    fi

    if [ $? -ne 0 ]; then
        write_file "\tWARNING: the openssh-server isn't installed."
        return ${RETURN_WARNING}
    fi

    sshd_cfg="/etc/ssh/sshd_config"
    if [ ! -e ${sshd_cfg} ]; then
        write_file "\tWARNING: the sshd_config file doesn't exist."
        return ${RETURN_WARNING}
    fi

    grep -iq "^PermitRootLogin yes" /etc/ssh/sshd_config
    if [ $? -ne 0 ]; then
        write_file "\tWARNING: the setting of \"PermitRootLogin\" must be to yes."
        return ${RETURN_WARNING}
    fi

    if [[ "${distro}" == "CentOS" || "${distro}" == "Baidu" || "${distro}" == "CentOS Stream" || 
        "${distro}" == "Rocky" || "${distro}" == "AlmaLinux" || "${distro}" == "rhel" ]]; then
        if [[ "${distro_version_major}" -ge "7" || "${distro}" = "Baidu" ]]; then
            systemctl status sshd 2> /dev/null | grep -q "active (running)"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the sshd service is not running."
                return ${RETURN_WARNING}
            fi
            flag=$(systemctl list-unit-files  | grep sshd.service | awk '{print $2}')
            if [ "$flag" = "disable" ] || [ "$flag" = "inactive" ]; then
                write_file "\tWARNING: the sshd service is disabled."
                write_file "\tWARNING: please enable sshd service."
                return ${RETURN_WARNING}
            fi
        else
            chkconfig --list | grep sshd | grep -qE "3:on|4:on|5:on"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the sshd service is disabled."
                write_file "\tWARNING: please enable sshd service."
                return ${RETURN_WARNING}
            fi
        fi
    fi 

    if [[ "${distro}" = "Ubuntu" || "${distro}" = "Debian" ]]; then
        if [ "$distro_version_major" -ge "16" ]; then
            systemctl status sshd 2> /dev/null | grep -qE "ssh.service; enabled|running"
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the sshd service is not running."
                return ${RETURN_WARNING}
            fi
        else
            service ssh status 2> /dev/null | head -n 5 | grep -q "running" 
            if [ $? -ne 0 ]; then
                write_file "\tWARNING: the ssh service is not running."
                return ${RETURN_WARNING}
            fi
        fi
    fi
    return ${RETURN_SUCCESS}
}