#!/usr/bin/env bash

function bd_check_passwd_cmd() {
    write_file ${split_line}
    write_file "[ check password command ]"

    command -v passwd 1>/dev/null 2>&1
    if [ $? -ne 0 ]; then
        write_file "\tWARNING: can't find passwd command."
        write_file "\tWARNING: please make sure that 'passwd' is installed on your system."
        return ${RETURN_WARNING}
    fi

    if [ ! -f /etc/shadow ]; then
        write_file "\tWARNING: can't find /etc/shadow file."
        return ${RETURN_WARNING}
    fi

    if [ ! -w /etc/shadow ]; then
        write_file "\tWARNING: the /etc/shadow file is not writable."
        return ${RETURN_WARNING}
    fi

    if [ ! -f /etc/passwd ]; then
        write_file "\tWARNING: can't find /etc/passwd file."
        return ${RETURN_WARNING}
    fi

    if [ ! -w /etc/passwd ]; then
        write_file "\tWARNING: the /etc/passwd file is not writable."
    fi

    return ${RETURN_SUCCESS}
}

function bd_check_root(){
    write_file ${split_line}
    write_file "[ check root user ]"
    
    if [ ! -f /etc/passwd ]; then
        write_file "\tWARNING: can't find /etc/passwd file."
        return ${RETURN_WARNING}
    fi
    grep -q "^root:x:0:0" /etc/passwd
    if [ $? -eq 0 ]; then
        return ${RETURN_SUCCESS}
    else
        write_file "\tWARNING: in /etc/passwd, root user does not exist or format is incorrect."
        return ${RETURN_WARNING}
    fi
}